@@ -34,13 +34,13 @@ impl Data {
     pub fn render<W: Write>(self, mut device: W, args: ParseArgs) -> io::Result<()> {
         for table_schema in self.schemas.values() {
             device.write_all(format!("\
-CREATE TABLE {table_name} (
+CREATE TABLE {schema_name}.{table_name} (
     {fid_col} INTEGER NOT NULL PRIMARY KEY,
     {col_definitions},
     {geom_field} geometry({geom_type}, {srid}) NOT NULL
 );
 
-CREATE SEQUENCE {table_name}_{fid_col}_seq
+CREATE SEQUENCE {schema_name}.{table_name}_{fid_col}_seq
     AS integer
     START WITH 1
     INCREMENT BY 1
@@ -48,11 +48,12 @@ CREATE SEQUENCE {table_name}_{fid_col}_seq
     NO MAXVALUE
     CACHE 1;
 
-ALTER SEQUENCE {table_name}_{fid_col}_seq OWNED BY {table_name}.{fid_col};
+ALTER SEQUENCE {schema_name}.{table_name}_{fid_col}_seq OWNED BY {schema_name}.{table_name}.{fid_col};
 
-ALTER TABLE ONLY {table_name} ALTER COLUMN {fid_col} SET DEFAULT nextval('{table_name}_{fid_col}_seq'::regclass);
+ALTER TABLE ONLY {schema_name}.{table_name} ALTER COLUMN {fid_col} SET DEFAULT nextval('{schema_name}.{table_name}_{fid_col}_seq'::regclass);
 
 ",
+                schema_name = args.schema,
                 table_name = table_schema.name().to_owned(),
                 fid_col = args.fid_col,
                 geom_field = args.geom_field,
