@@ -3,7 +3,8 @@ use clap::ArgMatches;
 pub struct ParseArgs<'a> {
     pub geom_field: &'a str,
     pub schema: &'a str,
-    pub id_col: &'a str,
+    pub fid_col: &'a str,
+    pub srid: u16,
 }
 
 // TODO consider to put this behind a feature flag
@@ -12,7 +13,8 @@ impl<'a> ParseArgs<'a> {
         ParseArgs {
             geom_field: matches.value_of("geom").unwrap(),
             schema: matches.value_of("schema").unwrap(),
-            id_col: matches.value_of("id").unwrap(),
+            fid_col: matches.value_of("fid").unwrap(),
+            srid: matches.value_of("srs").unwrap().parse().unwrap(),
         }
     }
 }
